import { actions } from 'astro:actions';
import { teams } from './state.ts';
import type { Team } from './types.ts';
import { actionErrorPopup } from '@util/action.ts';

export async function fetchTeams(name: string | null, username: string | null) {
  const { data, error } = await actions.team.teams({ name: name, username: username });
  if (error) {
    actionErrorPopup(error);
    return;
  }

  teams.set(data.teams);
}

export async function addTeam(team: Team) {
  const { data, error } = await actions.team.addTeam(team);
  if (error) {
    actionErrorPopup(error);
    return;
  }

  teams.update((old) => {
    old.push(Object.assign(team, { id: data.id }));
    return old;
  });
}

export async function editTeam(team: Team) {
  const { error } = await actions.team.editTeam(team);
  if (error) {
    actionErrorPopup(error);
    return;
  }

  teams.update((old) => {
    const index = old.findIndex((a) => a.id == team.id);
    old[index] = team;
    return old;
  });
}
