import { actions } from 'astro:actions';
import { actionErrorPopup } from '@util/action.ts';
import { blockedUsers } from '@app/admin/usersBlocked/state.ts';
import type { BlockedUser } from '@app/admin/usersBlocked/types.ts';

export async function fetchBlockedUsers() {
  const { data, error } = await actions.user.blocked();
  if (error) {
    actionErrorPopup(error);
    return;
  }

  blockedUsers.set(data.blocked);
}

export async function addBlockedUser(blockedUser: BlockedUser) {
  const { data, error } = await actions.user.addBlocked(blockedUser);
  if (error) {
    actionErrorPopup(error);
    return;
  }

  blockedUsers.update((old) => {
    old.push(Object.assign(blockedUser, { id: data.id }));
    return old;
  });
}

export async function editBlockedUser(blockedUser: BlockedUser) {
  const { data, error } = await actions.user.editBlocked(blockedUser);
  if (error) {
    actionErrorPopup(error);
    return;
  }

  blockedUsers.update((old) => {
    const index = old.findIndex((a) => a.id == user.id);
    old[index] = blockedUser;
    return old;
  });
}
